#ifndef LIBKYDEVICESEC_AP_H
#define LIBKYDEVICESEC_AP_H

#ifdef __cplusplus
extern "C" {
#endif

typedef enum _kdk_ap_status {
    KDK_AP_DISABLE = 0,
    KDK_AP_ENABLE,
} kdk_ap_status;

typedef enum _kdk_ap_mode {
    KDK_AP_MODE_NORMAL = 0,
    KDK_AP_MODE_BLACKLIST,
    KDK_AP_MODE_WHITELIST,
} kdk_ap_mode;

/**
 * 热点管控
 */

/**
 * @brief 设置热点管控状态
 * @param status [in] 热点管控状态,参见kdk_ap_status
 * @return int 返回0表示成功，返回-1表示失败
 */
extern int kdk_device_set_wireless_ap_status(int status);

/**
 * @brief 获取热点管控状态
 * @return int 返回0表示禁用，返回1表示启用，返回-1表示失败
 */
extern int kdk_device_get_wireless_ap_status();

/**
 * @brief 设置热点管控黑白名单模式
 * @param mode[in]: 热点管控模式，参见kdk_ap_mode
 * @return int 返回0表示成功，返回-1表示失败
 */
extern int kdk_device_set_wireless_ap_bwm(int mode);

/**
 * @brief 获取热点管控黑白名单模式
 * @return 返回0表示普通模式，返回1表示黑名单模式，返回2表示白名单模式，返回-1表示失败
 */
extern int kdk_device_get_wireless_ap_bwm();

/**
 * @brief 设置热点管控黑名单
 * @param mac[in]: 接入设备mac地址
 * @return int 返回0表示成功，返回-1表示失败
 */
extern int kdk_device_set_wireless_ap_blacklist(const char *mac);

/**
 * @brief 删除热点管控黑名单节点
 * @param mac[in]: 接入设备mac地址
 * @return int 返回0表示成功，返回-1表示失败
 */
extern int kdk_device_del_wireless_ap_blacklist(const char *mac);

/**
 * @brief 清空热点管控黑名单
 * @return int 返回0表示成功，返回-1表示失败
 */
extern int kdk_device_clear_wireless_ap_blacklist();

/**
 * @brief 获取热点管控黑名单
 * @param len[out]:黑名单长度
 * @return 黑名单列表
 */
extern char** kdk_device_get_wireless_ap_blacklist(int *len);

/**
 * @brief 设置热点管控白名单
 * @param mac[in]: 接入设备mac地址
 * @return int 返回0表示成功，返回-1表示失败
 */
extern int kdk_device_set_wireless_ap_whitelist(const char *mac);

/**
 * @brief 删除热点管控白名单节点
 * @param mac[in]: 接入设备mac地址
 * @return int 返回0表示成功，返回-1表示失败
 */
extern int kdk_device_del_wireless_ap_whitelist(const char *mac);

/**
 * @brief 清空热点管控白名单
 * @return int 返回0表示成功，返回-1表示失败
 */
extern int kdk_device_clear_wireless_ap_whitelist();

/**
 * @brief 获取热点管控白名单
 * @param len[out]:白名单长度
 * @return 白名单列表
 */
extern char** kdk_device_get_wireless_ap_whitelist(int *len);

#ifdef __cplusplus
}
#endif

#endif
