#ifndef LIBKYDEVICESEC_BLUETOOTH_H
#define LIBKYDEVICESEC_BLUETOOTH_H

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief 蓝牙管控 
 * 
 */

typedef enum _kdk_bluetooth_status {
    KDK_BLUETOOTH_DISABLE = 0,
    KDK_BLUETOOTH_ENABLE,
} kdk_bluetooth_status;

typedef enum _kdk_bluetooth_mode {
    KDK_BLUETOOTH_MODE_NORMAL = 0,
    KDK_BLUETOOTH_MODE_BLACKLIST,
    KDK_BLUETOOTH_MODE_WHITELIST,
} kdk_bluetooth_mode;

typedef enum _kdk_bluetooth_type {
    KDK_BLUETOOTH_TYPE_AUDIO = 0,
    KDK_BLUETOOTH_TYPE_KEYBOARDMOUSE,
    KDK_BLUETOOTH_TYPE_PHONE,
    KDK_BLUETOOTH_TYPE_COMPUTER,
    KDK_BLUETOOTH_TYPE_END
    
} kdk_bluetooth_type;

/**
 * @brief 设置蓝牙管控状态
 * 
 * @param status [in] kdk_bluetooth_status
 * @return int 返回0表示成功，返回其他表示失败
 */
extern int kdk_device_set_bluetooth_status(int status);

/**
 * @brief 获取蓝牙管控状态
 * 
 * @return int 返回kdk_bluetooth_status, 返回其他表示失败
 */
extern int kdk_device_get_bluetooth_status();

/**
 * @brief 设置接入蓝牙设备类型的管控状态
 * 
 * @param type [in] kdk_bluetooth_type
 * @param status [in] kdk_bluetooth_status
 * @return int 返回0表示成功，返回其他表示失败
 */
extern int kdk_device_set_bluetooth_type_status(int type, int status);

/**
 * @brief 获取接入蓝牙设备类型的管控状态
 * 
 * @param type [in] kdk_bluetooth_type
 * @return int 返回0表示成功，返回其他表示失败
 */
extern int kdk_device_get_bluetooth_type_status(int type);

/**
 * @brief 设置接入蓝牙设备黑白名单模式
 * 
 * @param mode [in] kdk_bluetooth_mode
 * @return int 返回0表示成功，返回其他表示失败
 */
extern int kdk_device_set_bluetooth_bwm(int mode);

/**
 * @brief 获取接入蓝牙设备黑白名单模式
 * 
 * @return int 返回kdk_bluetooth_mode, 返回其他表示失败
 */
extern int kdk_device_get_bluetooth_bwm();

/**
 * @brief 添加接入蓝牙设备的mac地址到黑名单
 * 
 * @param mac [in] 接入蓝牙设备的mac地址
 * @return int 返回0表示成功，返回其他表示失败
 */
extern int kdk_device_add_bluetooth_blacklist(const char *mac);

/**
 * @brief 从接入蓝牙设备黑名单删除一个蓝牙设备
 * 
 * @param mac [in] 接入蓝牙设备的mac地址
 * @return int 返回0表示成功，返回其他表示失败
 */
extern int kdk_device_del_bluetooth_blacklist(const char *mac);

/**
 * @brief 清空接入蓝牙设备黑名单
 * 
 * @return int 返回0表示成功，返回其他表示失败
 */
extern int kdk_device_clear_bluetooth_blacklist();

/**
 * @brief 获取接入蓝牙设备黑名单
 * 
 * @param len [out] 黑名单长度 
 * @return char** 黑名单列表
 */
extern char** kdk_device_get_bluetooth_blacklist(int *len);

/**
 * @brief 添加接入蓝牙设备mac地址到白名单
 * 
 * @param mac [in] 接入蓝牙设备的mac地址
 * @return int 返回0表示成功，返回其他表示失败
 */
extern int kdk_device_add_bluetooth_whitelist(const char *mac);

/**
 * @brief 从接入蓝牙设备白名单删除一个蓝牙设备
 * 
 * @param mac [in] 接入蓝牙设备的mac地址
 * @return int 返回0表示成功，返回其他表示失败
 */
extern int kdk_device_del_bluetooth_whitelist(const char *mac);

/**
 * @brief 清空接入蓝牙设备白名单
 * 
 * @return int 返回0表示成功，返回其他表示失败
 */
extern int kdk_device_clear_bluetooth_whitelist();

/**
 * @brief 获取接入蓝牙设备白名单
 * 
 * @param len [out] 白名单长度
 * @return char** 白名单列表
 */
extern char** kdk_device_get_bluetooth_whitelist(int *len);



#ifdef __cplusplus
}
#endif

#endif